=== modified file 'delivery_mechanism/delivery_mechanism.py'
--- delivery_mechanism/delivery_mechanism.py	2014-09-30 08:56:29 +0000
+++ delivery_mechanism/delivery_mechanism.py	2014-10-02 13:28:56 +0000
@@ -69,6 +69,10 @@
             string='Date end',
             readonly=True,
         ),
+        'error_msg': fields.boolean(
+            string='Error',
+            readonly=True,
+        ),
     }
 
     _defaults = {
@@ -391,6 +395,13 @@
                 if nd_ids:
                     res[pick_id]['progress_memory_not_done'] = 1
 
+                    err_ids = mem_obj.search(cr, uid, [
+                        ('id', 'in', nd_ids),
+                        ('error_msg', '!=', False),
+                    ], context=context)
+                    if err_ids:
+                        res[pick_id]['progress_memory_error'] = 1
+
         return res
 
 
@@ -425,6 +436,16 @@
             readonly=True,
             multi='process',
         ),
+        'progress_memory_error': fields.function(
+            _get_progress_memory,
+            method=True,
+            string='Processing error',
+            type='char',
+            size=256,
+            store=False,
+            readonly=True,
+            multi='process',
+        ),
     }
 
     def go_to_processing_wizard(self, cr, uid, ids, context=None):
@@ -816,16 +837,25 @@
         """
         Call the do_incoming_shipment() method with a new cursor.
         """
+        inc_proc_obj = self.pool.get('stock.incoming.processor')
+
         # Create new cursor
         import pooler
         new_cr = pooler.get_db(cr.dbname).cursor()
 
+        res = True
+
         try:
             # Call do_incoming_shipment()
             res = self.do_incoming_shipment(new_cr, uid, wizard_ids, context=context)
             new_cr.commit()
         except Exception, e:
             new_cr.rollback()
+
+            for wiz in inc_proc_obj.read(new_cr, uid, wizard_ids, ['picking_id'], context=context):
+                self.update_processing_info(new_cr, uid, wiz['picking_id'][0], False, {
+                    'error_msg': str(e),
+                }, context=context)
         finally:
             # Close the cursor
             new_cr.close()

=== modified file 'delivery_mechanism/delivery_mechanism_view.xml'
--- delivery_mechanism/delivery_mechanism_view.xml	2014-09-08 09:37:40 +0000
+++ delivery_mechanism/delivery_mechanism_view.xml	2014-10-02 13:28:56 +0000
@@ -40,17 +40,18 @@
             <field name="type">form</field>
             <field name="arch" type="xml">
                 <form string="Picking processing info">
-                    <field name="picking_id" />
-                    <newline />
+                    <field name="picking_id" colspan="4" />
+                    <separator colspan="4" string="Processing status" />
                     <field name="start_date" />
                     <field name="end_date" />
                     <field name="progress_line" />
-                    <newline />
                     <field name="create_bo" />
-                    <newline />
                     <field name="close_in" />
-                    <newline />
                     <field name="prepare_pick" />
+                    <group colspan="4" attrs="{'invisible': [('error_msg', '=', False)]}">
+                        <separator colspan="4" string="Error" />
+                        <field name="error_msg" widget="text" nolabel="1" colspan="4" />
+                    </group>
                     <separator colspan="4" string="Actions" />
                     <button name="refresh" type="object" string="Refresh" icon="gtk-refresh" colspan="2" />
                     <button name="close" type="object" string="Close" icon="gtk-close" colspan="2" />

=== modified file 'stock_override/stock_view.xml'
--- stock_override/stock_view.xml	2014-09-25 13:10:10 +0000
+++ stock_override/stock_view.xml	2014-10-02 13:28:56 +0000
@@ -519,18 +519,30 @@
         	<field name="arch" type="xml">
         		<form string="Incoming Shipments">
                     <field name="progress_memory_not_done" invisible="1" />
+                    <field name="progress_memory_error" invisible="1" />
                     <group colspan="6">
                         <html>
                             <p id="view_incoming_in_progress"
                                style="display:none; text-align:center; color: red; font-weight: bold; font-size: 1.2em;">
                                WARNING: The processing of this incoming shipment is currently in progress, any modifications you make will not be considered.
                             </p>
+                            <p id="view_incoming_in_progress_error"
+                               style="display:none; text-align:center; color: red; font-weight: bold; font-size: 1.2em;">
+                               ERROR: The processing of this incoming shipment has returned an error, please open the processing wizard to show the error.
+                            </p>
                             <script language="javascript">
-                                var is_synced = $('#progress_memory_not_done').val();
-                                if (is_synced == "1") {
+                                var is_not_done = $('#progress_memory_not_done').val();
+                                var is_error = $('#progress_memory_error').val();
+                                if (is_not_done == "1") {
                                     msg_dom = $('#view_incoming_in_progress')
                                     msg_dom.show();
                                 }
+                                if (is_error == "1") {
+                                    msg_dom = $('#view_incoming_in_progress_error')
+                                    msg_dom.show()
+                                    msg_dom_done = $('#view_incoming_in_progress')
+                                    msg_dom_done.hide()
+                                }
                             </script>
                         </html>
                     </group>

